/* commandInterface.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef COMMANDINTERFACE_H
#define COMMANDINTERFACE_H

#include "playerDef.h"

#include <string>
#include <unistd.h>

class Player;

class CommandInterface {
public:
  CommandInterface(const string &command,
		   const PlayerDef::Status &status,
		   Player *player);
  ~CommandInterface();

  int get_fd() const;
  bool read_status();
  bool child_exited(pid_t pid);

  bool anything_played() const;
  double get_current_time() const;

  int get_total_frames() const;
  double get_total_time() const;

private:
  void line_up_process_status(const string &input);
  void match_literal(const string &line, const string &literal, int &next_pos);
  void extract_integer(const string &line, int &next_pos, int &result);
  void extract_float(const string &line, int &next_pos, double &result);
  void extract_time(const string &line, int &next_pos, double &result);
  void match_status(const string &line);
  
  int _pid;
  int _fd;
  string _last_input;

  bool _anything_played;
  int _total_frames;
  double _total_time;

  double _current_position;

  const PlayerDef::Status &_status;
  Player *_player;
};

#endif
