/* postgresQueryResult.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef POSTGRESQUERYRESULT_H
#define POSTGRESQUERYRESULT_H

#ifdef USE_PGSQL

#include "queryResult.h"

#include <libpq-fe.h>

class PostgresDatabase;

class PostgresQueryResult : public QueryResultBase {
public:
  PostgresQueryResult(PostgresDatabase &db);
  virtual ~PostgresQueryResult();

  virtual bool success() const;
  virtual string get_error_message() const;

  virtual int get_num_columns() const;
  virtual string get_column_name(int c) const;
  virtual DataCell::Type get_column_type(int c) const;
  
  virtual int get_num_rows() const;
  virtual DataCell get_cell(int r, int c) const;
  const char *get_cell_raw(int r, int c) const;

  void set_pg_result(PGresult *result);
  void set_error_message(const string &msg);
  
private:
  PostgresDatabase &get_db() const { return (PostgresDatabase &)_db; }
  PGresult *_pg_result;
  string _error_message;
};

#endif // USE_PGSQL

#endif
