/* sfPlayer.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef SFPLAYER_H
#define SFPLAYER_H

#include <string>

extern "C" {
  #include <audiofile.h>
}

class SFPlayer {
public:
  SFPlayer(int soundfile_fd, const string &soundfile_name, 
	   const string &audio_device, int block_samples);
  ~SFPlayer();

  bool is_valid() const;
  double get_length() const;

  bool play(double start, double length, bool verbose);

private:
  bool open_audio_device();

  bool _is_valid;
  AFfilehandle _sound_file;

  // Parameters about the sound file supplied by the AL library
  int _num_channels;
  int _sample_format;
  int _sample_width;
  double _sample_rate;
  int _sample_bytes;
  int _num_frames;

  // The file descriptor and device name of the sound card.
  int _audio_fd;
  string _audio_device;

  // The frame that will be next fed to the audio device.
  int _current_frame;

  // The frame number that marks the end of output.  This frame will
  // not be fed to the audio device.
  int _stop_frame;

  // The samples as read from the sound file, for sending to the audio
  // device.
  unsigned char *_samples;
  int _block_samples;
};

#endif
